package com.miaxis.app.controller.user;

import com.miaxis.app.user.dto.UserDto;
import com.miaxis.app.user.service.IUserInfoService;
import com.miaxis.app.user.vo.UserVo;
import com.miaxis.common.aliyunOSS.AliyunConfig;
import com.miaxis.common.aliyunOSS.AliyunUpload;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.SecurityUtils;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 【用户信息】Controller
 *
 * @author wwl
 * @date 2020-12-23
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX+"/user/info")
@Api(tags={"【app-普通用户信息】"})
public class UserInfoController extends BaseController{

    @Autowired
    private IUserInfoService userInfoService;

    /**
     * 查询用户信息列表
     */
    @GetMapping("/list")
    @ApiOperation("查询用户信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<UserInfo> list(@ModelAttribute UserInfo userInfo){
        startPage();
        List<UserInfo> list = userInfoService.list();
        return toResponsePageInfo(list);
    }


    /**
     * 获取用户信息详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取用户信息详细信息")
    public Response<UserInfo> getInfo(
            @ApiParam(name = "id", value = "用户信息参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(userInfoService.selectUserInfoById(id));
    }


    /**
     * 修改用户信息
     */
    @PutMapping
    @ApiOperation("修改用户信息")
    public Response<Integer> edit(@RequestBody UserInfo userInfo){
        return toResponse(userInfoService.updateUserInfo(userInfo));
    }

    /**
     * 删除用户信息
     */
	@DeleteMapping("/{ids}")
    @ApiOperation("删除用户信息")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "用户信息ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(userInfoService.deleteUserInfoByIds(ids));
    }

    /**
     * 上传身份证正反面,及人像图片
     * uploadIdCardAndHeadPicture
     */
    @PostMapping("/uploadIdCardAndHeadPicture")
    @ApiOperation("上传身份证正反面,及人像图片")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type",value = "idCardFront:身份证正面、idCardReverse:身份证反面、faces:人像" ,dataType = "String",required = true),
            @ApiImplicitParam(name = "multFile", value = "上传文件", required = true, dataType = "String")
    })
    public Response uploadIdCardAndHeadPicture(String type,MultipartFile multFile) throws IOException {
        String savePath = AliyunConfig.gzpt_user + type + "/"
                + new SimpleDateFormat("yyyyMM").format(new Date()) + "/";
        String fileName = System.currentTimeMillis() + ".jpg";
        String fileUrl = AliyunUpload.uploadForStream(multFile.getInputStream(), savePath, fileName);
        Map<String, Object> map = new HashMap<>();
        map.put("filePath",savePath+fileName);//文件路径名
        map.put("fileUrl",fileUrl);//文件访问路径
        return Response.success(map);
    }

    /**
     * 删除文件
     * uploadIdCardAndHeadPicture
     */
    @PostMapping("/deleteCardAndHeadPicture")
    @ApiOperation("删除文件")
    @ApiImplicitParam(name = "filePath",value = "文件路径(filePath)" ,dataType = "String",required = true)
    public Response deleteCardAndHeadPicture(String filePath) {
        boolean b = AliyunUpload.deleteObject(filePath);
        if (!b)return Response.error();
        return Response.success();
    }

    /**
     * 保存用户报名信息
     * uploadIdCardAndHeadPicture
     */
    @PostMapping("/saveUserInformation")
    @ApiOperation("保存用户报名信息")
    public Response saveUserInformation(UserDto userDto) {
        try {
            return userInfoService.saveUserInformation(userDto);
        }catch (Exception e){
            return Response.error();
        }
    }

    /**
     * 注册报名获取短信验证码
     * @return
     */
    @ApiOperation("注册报名获取短信验证码")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type",value = "login:用户登录验证码、modify:修改手机验证码、signUp:注册报名验证码" ,dataType = "String",required = true),
            @ApiImplicitParam(name = "phone", value = "手机号码", required = true, dataType = "String")
    })
    @PostMapping(value = "/sendSignUpVerificationCode")
    public Response sendSignUpVerificationCode(String type,String phone){

        return userInfoService.sendSignUpVerificationCode(type,phone);
    }

    /**
     * 修改手机号获取短信验证码
     * @return
     */
    @ApiOperation("修改手机号获取短信验证码")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type",value = "login:用户登录验证码、modify:修改手机验证码、signUp:注册报名验证码" ,dataType = "String",required = true),
            @ApiImplicitParam(name = "phone", value = "手机号码", required = true, dataType = "String")
    })
    @PostMapping(value = "/sendModifyVerificationCode")
    public Response sendModifyVerificationCode(String type,String phone){
        //获取当前用户
        SysUser user = SecurityUtils.getLoginUser().getUser();

        return userInfoService.sendModifyVerificationCode(user,type,phone);
    }


    /**
     * 修改用户手机号
     */
    @PostMapping("/modifyPhoneNumber")
    @ApiOperation("修改用户手机号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "smsCodeType,", value = "login:用户登录验证码、modify:修改手机验证码、signUp:注册报名验证码", required = true, dataType = "String"),
            @ApiImplicitParam(name = "phone", value = "手机号码", required = true, dataType = "String"),
            @ApiImplicitParam(name = "verificationCode", value = "短信验证码", required = true, dataType = "String")
    })
    public Response modifyPhoneNumber(String smsCodeType,String phone,String verificationCode){
        //获取当前用户
        SysUser user = SecurityUtils.getLoginUser().getUser();
        //修改手机号
        return userInfoService.modifyPhoneNumber(smsCodeType,phone,verificationCode,user);
    }

    /**
     * 查询我的报名信息
     */
    @GetMapping("/getMyRegistrationInformation")
    @ApiOperation("查询我的报名信息")
    @ApiImplicitParam(name = "userId",value = "用户id" ,dataType = "String",required = true)
    public Response<UserVo> getMyRegistrationInformation(String userId){

        return userInfoService.getMyRegistrationInformation(userId);
    }

}
