package com.miaxis.app.user.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.miaxis.app.user.vo.UserVo;
import com.miaxis.common.core.domain.entity.UserInfo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 用户信息Mapper接口
 *
 * @author miaxis
 * @date 2020-12-23
 */
public interface UserInfoMapper extends BaseMapper<UserInfo> {
    /**
     * 查询用户信息
     *
     * @param id 用户信息ID
     * @return 用户信息
     */
    public UserInfo selectUserInfoById(Long id);

    /**
     * 查询用户信息列表
     *
     * @param userInfo 用户信息
     * @return 用户信息集合
     */
    public List<UserInfo> selectUserInfoList(UserInfo userInfo);

    /**
     * 新增用户信息
     *
     * @param userInfo 用户信息
     * @return 结果
     */
    public int insertUserInfo(UserInfo userInfo);

    /**
     * 修改用户信息
     *
     * @param userInfo 用户信息
     * @return 结果
     */
    public int updateUserInfo(UserInfo userInfo);

    /**
     * 删除用户信息
     *
     * @param id 用户信息ID
     * @return 结果
     */
    public int deleteUserInfoById(Long id);

    /**
     * 批量删除用户信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteUserInfoByIds(Long[] ids);

    /**
     * 获取我的报名信息
     * @param userId
     * @return
     */
    UserVo getMyRegistrationInformation(@Param("userId") String userId);
}
