package com.miaxis.app.user.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.miaxis.app.user.dto.UserDto;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.SysUser;
import com.miaxis.common.core.domain.entity.UserInfo;

/**
 * 用户信息Service接口
 *
 * @author miaxis
 * @date 2020-12-23
 */
public interface IUserInfoService extends IService<UserInfo>{
    /**
     * 查询用户信息
     *
     * @param id 用户信息ID
     * @return 用户信息
     */
    public UserInfo selectUserInfoById(Long id);

    /**
     * 修改用户信息
     *
     * @param userInfo 用户信息
     * @return 结果
     */
    public int updateUserInfo(UserInfo userInfo);

    /**
     * 批量删除用户信息
     *
     * @param ids 需要删除的用户信息ID
     * @return 结果
     */
    public int deleteUserInfoByIds(Long[] ids);


    /**
     * 修改手机号
     * @param phone
     * @param verificationCode
     * @return
     */
    Response modifyPhoneNumber(String smsCodeType,String phone, String verificationCode,SysUser user);

    /**
     * 保存用户报名信息
     * @param userDto
     * @return
     */
    Response saveUserInformation(UserDto userDto);

    /**
     * 注册报名获取短信验证码
     * @param type
     * @param phone
     * @return
     */
    Response sendSignUpVerificationCode(String type, String phone);

    /**
     * 修改手机号获取短信验证码
     * @param user
     * @param type
     * @param phone
     * @return
     */
    Response sendModifyVerificationCode(SysUser user, String type, String phone);


    /**
     * 获取我的报名信息
     * @param userId
     * @return
     */
    Response getMyRegistrationInformation(String userId);
}
